@@ -63,6 +63,11 @@ pub struct Wrk {
     /// IE: http://localhost:1234/some/uri.
     #[getset(get = "pub", set = "pub", get_mut = "pub")]
     url: String,
+    /// Wrk timeout in seconds
+    #[serde(skip)]
+    #[builder(default = "1")]
+    #[getset(get = "pub", set = "pub", get_mut = "pub")]
+    timeout: u8,
     /// Set of benchmarks for the current instance.
     #[builder(default)]
     #[getset(get = "pub", set = "pub", get_mut = "pub")]
@@ -113,6 +118,8 @@ impl Wrk {
             benchmark.connections().to_string(),
             "-d".to_string(),
             format!("{}s", benchmark.duration().as_secs()),
+            "--timeout".to_string(),
+            format!("{}s", self.timeout()),
             "-s".to_string(),
             lua_script.to_string_lossy().to_string(),
             url.to_string(),
@@ -120,7 +127,6 @@ impl Wrk {
     }
 
     fn wrk_result(&self, wrk_json: &str) -> WrkResult {
-        println!("AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA {}", wrk_json);
         match serde_json::from_str::<WrkResult>(wrk_json) {
             Ok(mut run) => {
                 let error_percentage = run.errors() / 100.0 * run.requests();
@@ -190,10 +196,8 @@ impl Wrk {
             };
             *run.date_mut() = date;
             *run.benchmark_mut() = benchmark.clone();
-            println!("Current run: {:?}", run);
             self.benchmarks_mut().push(run);
         }
-        println!("SCRIPT: {}", script_file.path().display());
         script_file.keep()?;
         self.dump(date)?;
         Ok(())
